@@ -107,7 +107,34 @@ def a_chunk(url, target_directory, lst_distinct_column, lst_column_match=[], sor
     return requests_get_write(target_directory, url, write)
 
 
-def it_chunk(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
+def it_chunk_pd(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
     return it_mp_f(a_chunk,
                    [tuple([url, target_directory, lst_distinct_column,
                            lst_column_match, sort_column]) for url in lst_url])
+
+
+def a_chunk_pl(url, target_directory, lst_distinct_column, lst_column_match=[], sort_column=''):
+    def write(bytes1):
+        df = pl.read_csv(bytes1)
+        df = df.distinct(subset=lst_distinct_column)
+        condition = ''
+        for lst_col_val in lst_column_match:
+            condition += f"""(pl.col('{lst_col_val[0]}')=='{lst_col_val[1]}') | """
+        condition = condition[:-3]
+        df = df.filter(eval(condition))
+        if sort_column:
+            df = df.sort(sort_column)
+        bytesio_csv = BytesIO()
+        df.to_csv(bytesio_csv, has_header=False)
+        bytesio_gzip = BytesIO()
+        with gzip.open(bytesio_gzip, 'wb') as f:
+            f.write(bytesio_csv.getvalue())
+        return bytesio_gzip.getvalue()
+
+    return requests_get_write(target_directory, url, write)
+
+
+def it_chunk_pl(lst_url, target_directory, lst_distinct_column, lst_column_match, sort_column):
+    return it_mp_f(a_chunk_pl,
+                   [tuple([url, target_directory, lst_distinct_column,
+                           lst_column_match, sort_column]) for url in lst_url])
