@@ -3,7 +3,7 @@ import sys
 
 import requests
 
-from cameo_claw import it_distinct, it_streaming, it_group, it_filter, server
+from cameo_claw import it_distinct, it_streaming_pd, it_group, it_filter, server
 import time
 from cameo_claw.log import log
 
@@ -197,7 +197,7 @@ def get_lst_url_by_date(lst_device_id):
 def test_it_download():
     target_directory = './data/topic_download/'
     int_total = len(get_lst_url_taipei_100())
-    for int_progress, done_url in it_streaming(get_lst_url_taipei_100(), target_directory):
+    for int_progress, done_url in it_streaming_pd(get_lst_url_taipei_100(), target_directory):
         # print_progress(done_url, int_progress, int_total)
         pass
 
